@@ -14,7 +14,7 @@ import (
 )
 
 // Version is a version number.
-var version = "0.8.5"
+var version = "0.9.3"
 
 // UI is a user interface which is a global variable for mocking.
 var UI cli.Ui
@@ -83,6 +83,11 @@ func initCommands() map[string]cli.CommandFactory {
 				Meta: meta,
 			}, nil
 		},
+		"opentofu": func() (cli.Command, error) {
+			return &command.OpenTofuCommand{
+				Meta: meta,
+			}, nil
+		},
 		"provider": func() (cli.Command, error) {
 			return &command.ProviderCommand{
 				Meta: meta,
