@@ -10,77 +10,30 @@ import (
 	"github.com/minamijoyo/tfupdate/tfregistry"
 )
 
-// mockTFRegistryClient is a mock TFRegistryAPI implementation.
+// mockTFRegistryClient is a mock implementation of tfregistry.API
 type mockTFRegistryClient struct {
-	moduleRes   *tfregistry.ModuleLatestForProviderResponse
-	providerRes *tfregistry.ProviderLatestResponse
+	moduleRes   *tfregistry.ListModuleVersionsResponse
+	providerRes *tfregistry.ListProviderVersionsResponse
 	err         error
 }
 
-var _ TFRegistryAPI = (*mockTFRegistryClient)(nil)
+var _ tfregistry.API = (*mockTFRegistryClient)(nil)
 
-func (c *mockTFRegistryClient) ModuleLatestForProvider(ctx context.Context, req *tfregistry.ModuleLatestForProviderRequest) (*tfregistry.ModuleLatestForProviderResponse, error) { // nolint revive unused-parameter
+func (c *mockTFRegistryClient) ListModuleVersions(_ context.Context, _ *tfregistry.ListModuleVersionsRequest) (*tfregistry.ListModuleVersionsResponse, error) {
 	return c.moduleRes, c.err
 }
 
-func (c *mockTFRegistryClient) ProviderLatest(ctx context.Context, req *tfregistry.ProviderLatestRequest) (*tfregistry.ProviderLatestResponse, error) { // nolint revive unused-parameter
+func (c *mockTFRegistryClient) ListProviderVersions(_ context.Context, _ *tfregistry.ListProviderVersionsRequest) (*tfregistry.ListProviderVersionsResponse, error) {
 	return c.providerRes, c.err
 }
 
-func TestNewTFRegistryClient(t *testing.T) {
-	cases := []struct {
-		baseURL string
-		want    string
-		ok      bool
-	}{
-		{
-			baseURL: "",
-			want:    "https://registry.terraform.io/",
-			ok:      true,
-		},
-		{
-			baseURL: "https://registry.terraform.io/",
-			want:    "https://registry.terraform.io/",
-			ok:      true,
-		},
-		{
-			baseURL: "http://localhost/",
-			want:    "http://localhost/",
-			ok:      true,
-		},
-		{
-			baseURL: `https://registry\.terraform.io/`,
-			want:    "",
-			ok:      false,
-		},
-	}
-
-	for _, tc := range cases {
-		config := TFRegistryConfig{
-			BaseURL: tc.baseURL,
-		}
-		got, err := NewTFRegistryClient(config)
-
-		if tc.ok && err != nil {
-			t.Errorf("NewTFRegistryClient() with baseURL = %s returns unexpected err: %s", tc.baseURL, err)
-		}
-
-		if !tc.ok && err == nil {
-			t.Errorf("NewTFRegistryClient() with baseURL = %s expects to return an error, but no error", tc.baseURL)
-		}
-
-		if tc.ok {
-			if got.client.BaseURL.String() != tc.want {
-				t.Errorf("NewTFRegistryClient() with baseURL = %s returns %s, but want %s", tc.baseURL, got.client.BaseURL.String(), tc.want)
-			}
-		}
-	}
+func (c *mockTFRegistryClient) ProviderPackageMetadata(_ context.Context, _ *tfregistry.ProviderPackageMetadataRequest) (*tfregistry.ProviderPackageMetadataResponse, error) {
+	return nil, nil // dummy implementation as it's not used in tests
 }
 
 func TestNewTFRegistryModuleRelease(t *testing.T) {
 	cases := []struct {
 		source    string
-		api       TFRegistryAPI
 		namespace string
 		name      string
 		provider  string
@@ -88,7 +41,6 @@ func TestNewTFRegistryModuleRelease(t *testing.T) {
 	}{
 		{
 			source:    "hoge/fuga/piyo",
-			api:       &mockTFRegistryClient{},
 			namespace: "hoge",
 			name:      "fuga",
 			provider:  "piyo",
@@ -96,7 +48,6 @@ func TestNewTFRegistryModuleRelease(t *testing.T) {
 		},
 		{
 			source:    "hoge",
-			api:       &mockTFRegistryClient{},
 			namespace: "",
 			name:      "",
 			provider:  "",
@@ -105,28 +56,22 @@ func TestNewTFRegistryModuleRelease(t *testing.T) {
 	}
 
 	for _, tc := range cases {
-		config := TFRegistryConfig{
-			api: tc.api,
-		}
+		config := tfregistry.Config{}
 		got, err := NewTFRegistryModuleRelease(tc.source, config)
 
 		if tc.ok && err != nil {
-			t.Errorf("NewTFRegistryModuleRelease() with source = %s, api = %#v returns unexpected err: %s", tc.source, tc.api, err)
+			t.Errorf("NewTFRegistryModuleRelease() with source = %s returns unexpected err: %s", tc.source, err)
 		}
 
 		if !tc.ok && err == nil {
-			t.Errorf("NewTFRegistryModuleRelease() with source = %s, api = %#v expects to return an error, but no error", tc.source, tc.api)
+			t.Errorf("NewTFRegistryModuleRelease() with source = %s expects to return an error, but no error", tc.source)
 		}
 
 		if tc.ok {
 			r := got.(*TFRegistryModuleRelease)
 
-			if r.api != tc.api {
-				t.Errorf("NewTFRegistryModuleRelease() with source = %s, api = %#v sets api = %#v, but want %s", tc.source, tc.api, r.api, tc.api)
-			}
-
 			if !(r.namespace == tc.namespace && r.name == tc.name && r.provider == tc.provider) {
-				t.Errorf("NewTFRegistryModuleRelease() with source = %s, api = %#v returns (%s, %s, %s), but want (%s, %s, %s)", tc.source, tc.api, r.namespace, r.name, r.provider, tc.namespace, tc.name, tc.provider)
+				t.Errorf("NewTFRegistryModuleRelease() with source = %s returns (%s, %s, %s), but want (%s, %s, %s)", tc.source, r.namespace, r.name, r.provider, tc.namespace, tc.name, tc.provider)
 			}
 		}
 	}
@@ -135,21 +80,18 @@ func TestNewTFRegistryModuleRelease(t *testing.T) {
 func TestNewTFRegistryProviderRelease(t *testing.T) {
 	cases := []struct {
 		source       string
-		api          TFRegistryAPI
 		namespace    string
 		providerType string
 		ok           bool
 	}{
 		{
 			source:       "hoge/piyo",
-			api:          &mockTFRegistryClient{},
 			namespace:    "hoge",
 			providerType: "piyo",
 			ok:           true,
 		},
 		{
 			source:       "hoge",
-			api:          &mockTFRegistryClient{},
 			namespace:    "",
 			providerType: "",
 			ok:           false,
@@ -157,28 +99,22 @@ func TestNewTFRegistryProviderRelease(t *testing.T) {
 	}
 
 	for _, tc := range cases {
-		config := TFRegistryConfig{
-			api: tc.api,
-		}
+		config := tfregistry.Config{}
 		got, err := NewTFRegistryProviderRelease(tc.source, config)
 
 		if tc.ok && err != nil {
-			t.Errorf("NewTFRegistryProviderRelease() with source = %s, api = %#v returns unexpected err: %s", tc.source, tc.api, err)
+			t.Errorf("NewTFRegistryProviderRelease() with source = %s returns unexpected err: %s", tc.source, err)
 		}
 
 		if !tc.ok && err == nil {
-			t.Errorf("NewTFRegistryProviderRelease() with source = %s, api = %#v expects to return an error, but no error", tc.source, tc.api)
+			t.Errorf("NewTFRegistryProviderRelease() with source = %s expects to return an error, but no error", tc.source)
 		}
 
 		if tc.ok {
 			r := got.(*TFRegistryProviderRelease)
 
-			if r.api != tc.api {
-				t.Errorf("NewTFRegistryProviderRelease() with source = %s, api = %#v sets api = %#v, but want %s", tc.source, tc.api, r.api, tc.api)
-			}
-
 			if !(r.namespace == tc.namespace && r.providerType == tc.providerType) {
-				t.Errorf("NewTFRegistryProviderRelease() with source = %s, api = %#v returns (%s, %s), but want (%s, %s)", tc.source, tc.api, r.namespace, r.providerType, tc.namespace, tc.providerType)
+				t.Errorf("NewTFRegistryProviderRelease() with source = %s returns (%s, %s), but want (%s, %s)", tc.source, r.namespace, r.providerType, tc.namespace, tc.providerType)
 			}
 		}
 	}
@@ -192,8 +128,16 @@ func TestTFRegistryModuleReleaseListReleases(t *testing.T) {
 	}{
 		{
 			client: &mockTFRegistryClient{
-				moduleRes: &tfregistry.ModuleLatestForProviderResponse{
-					Versions: []string{"0.3.0", "0.2.0", "0.1.0"},
+				moduleRes: &tfregistry.ListModuleVersionsResponse{
+					Modules: []tfregistry.ModuleVersions{
+						{
+							Versions: []tfregistry.ModuleVersion{
+								{Version: "0.3.0"},
+								{Version: "0.2.0"},
+								{Version: "0.1.0"},
+							},
+						},
+					},
 				},
 				err: nil,
 			},
@@ -212,14 +156,12 @@ func TestTFRegistryModuleReleaseListReleases(t *testing.T) {
 
 	source := "hoge/fuga/piyo"
 	for _, tc := range cases {
-		// Set a mock client
-		config := TFRegistryConfig{
-			api: tc.client,
-		}
+		config := tfregistry.Config{}
 		r, err := NewTFRegistryModuleRelease(source, config)
 		if err != nil {
 			t.Fatalf("failed to NewTFRegistryModuleRelease(%s, %#v): %s", source, config, err)
 		}
+		r.(*TFRegistryModuleRelease).api = tc.client
 
 		got, err := r.ListReleases(context.Background())
 
@@ -245,8 +187,12 @@ func TestTFRegistryProviderReleaseListReleases(t *testing.T) {
 	}{
 		{
 			client: &mockTFRegistryClient{
-				providerRes: &tfregistry.ProviderLatestResponse{
-					Versions: []string{"0.3.0", "0.2.0", "0.1.0"},
+				providerRes: &tfregistry.ListProviderVersionsResponse{
+					Versions: []tfregistry.ProviderVersion{
+						{Version: "0.3.0"},
+						{Version: "0.2.0"},
+						{Version: "0.1.0"},
+					},
 				},
 				err: nil,
 			},
@@ -265,14 +211,12 @@ func TestTFRegistryProviderReleaseListReleases(t *testing.T) {
 
 	source := "hoge/piyo"
 	for _, tc := range cases {
-		// Set a mock client
-		config := TFRegistryConfig{
-			api: tc.client,
-		}
+		config := tfregistry.Config{}
 		r, err := NewTFRegistryProviderRelease(source, config)
 		if err != nil {
 			t.Fatalf("failed to NewTFRegistryProviderRelease(%s, %#v): %s", source, config, err)
 		}
+		r.(*TFRegistryProviderRelease).api = tc.client
 
 		got, err := r.ListReleases(context.Background())
 
