@@ -1,6 +1,9 @@
 package tfupdate
 
 import (
+	"context"
+	"path/filepath"
+
 	"github.com/hashicorp/hcl/v2/hclwrite"
 	"github.com/pkg/errors"
 	"github.com/zclconf/go-cty/cty"
@@ -24,7 +27,12 @@ func NewTerraformUpdater(version string) (Updater, error) {
 
 // Update updates the terraform version constraint.
 // Note that this method will rewrite the AST passed as an argument.
-func (u *TerraformUpdater) Update(f *hclwrite.File) error {
+func (u *TerraformUpdater) Update(_ context.Context, _ *ModuleContext, filename string, f *hclwrite.File) error {
+	if filepath.Base(filename) == ".terraform.lock.hcl" {
+		// skip a lock file.
+		return nil
+	}
+
 	for _, tf := range allMatchingBlocks(f.Body(), "terraform", []string{}) {
 		// set a version to attribute value only if the key exists
 		if tf.Body().GetAttribute("required_version") != nil {
